leaftools.remove_initial_rests_from_sequence
============================================

.. autofunction:: abjad.tools.leaftools.remove_initial_rests_from_sequence.remove_initial_rests_from_sequence
